import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'
import Iframe from '@/components/iframe/main'

import { componentsRouter, caseRouter, ruleRouter } from './modules/case.js'

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  componentsRouter,
  caseRouter,
  ruleRouter,
  // {
  //   path: '/permission',
  //   component: Layout,
  //   redirect: '/permission/page',
  //   alwaysShow: true, // will always show the root menu
  //   name: 'Permission',
  //   meta: {
  //     title: 'Permission',
  //     icon: 'lock',
  //     roles: ['admin', 'editor'] // you can set roles in root nav
  //   },
  //   children: [
  //     {
  //       path: 'page',
  //       component: () => import('@/views/admin/user'),
  //       name: 'PagePermission',
  //       meta: {
  //         title: 'Page Permission',
  //         roles: ['admin'] // or you can only set roles in sub nav
  //       }
  //     },
  //     {
  //       path: 'directive',
  //       component: () => import('@/views/admin/user'),
  //       name: 'DirectivePermission',
  //       meta: {
  //         title: 'Directive Permission'
  //         // if do not set roles, means: this page does not require permission
  //       }
  //     },
  //     {
  //       path: 'role',
  //       component: () => import('@/views/admin/user'),
  //       name: 'RolePermission',
  //       meta: {
  //         title: 'Role Permission',
  //         roles: ['admin']
  //       }
  //     }
  //   ]
  // },

  // {
  //   path: '/icon',
  //   component: Layout,
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/admin/user'),
  //       name: 'Icons',
  //       meta: { title: 'Icons', icon: 'icon' }
  //     }
  //   ]
  // },
  {
    path: '/login',
    component: () => import('@/login/sassLogin'),
    hidden: true
  },
  {
    path: '/editInfo',
    component: Layout,
    hidden: true,
    children: [{
      path: '/editInfo',
      name: '修改信息',
      component: () => import('@/views/admin/user/info'),
      meta: {
        title: '修改信息'
      }
    }]
  },
  {
    path: '/404',
    component: () => import('@/components/ErrorPage/404'),
    hidden: true
  },
  {
    path: '/403',
    component: () => import('@/components/ErrorPage/403'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    children: [
      {
        path: '/admin/user/info',
        component: () => import('@/views/admin/user/info'),
        name: 'editInfo',
        hidden: true,
        meta: { title: '修改信息', icon: 'dashboard', affix: true }
      }
    ]
  },
  {
    path: '/iframe',
    component: Layout,
    redirect: '/iframe',
    hidden: true,
    meta: {
      title: 'iframe'
    },
    children: [{
      path: ':routerPath',
      name: 'iframe',
      component: Iframe,
      props: true,
      meta: {
        title: 'iframe'
      }
    }]
  },
  { path: '*', component: Layout, redirect: '/404', hidden: true }
]

/**
 * asyncRoutes
 * the routes that need to be dynamically loaded based on user roles
 */
// export const asyncRoutes = [
//   {
//     path: '/permission',
//     component: Layout,
//     redirect: '/permission/page',
//     alwaysShow: true, // will always show the root menu
//     name: 'Permission',
//     meta: {
//       title: 'Permission',
//       icon: 'lock',
//       roles: ['admin', 'editor'] // you can set roles in root nav
//     },
//     children: [
//       {
//         path: 'page',
//         component: () => import('@/views/admin/user'),
//         name: 'PagePermission',
//         meta: {
//           title: 'Page Permission',
//           roles: ['admin'] // or you can only set roles in sub nav
//         }
//       },
//       {
//         path: 'directive',
//         component: () => import('@/views/admin/user'),
//         name: 'DirectivePermission',
//         meta: {
//           title: 'Directive Permission'
//           // if do not set roles, means: this page does not require permission
//         }
//       },
//       {
//         path: 'role',
//         component: () => import('@/views/admin/user'),
//         name: 'RolePermission',
//         meta: {
//           title: 'Role Permission',
//           roles: ['admin']
//         }
//       }
//     ]
//   },

//   {
//     path: '/icon',
//     component: Layout,
//     children: [
//       {
//         path: 'index',
//         component: () => import('@/views/admin/user'),
//         name: 'Icons',
//         meta: { title: 'Icons', icon: 'icon' }
//       }
//     ]
//   },

//   /** when your routing map is too long, you can split it into small modules **/
//   // componentsRouter,
//   // nestedRouter,

//   {
//     path: '/error',
//     component: Layout,
//     redirect: 'noRedirect',
//     name: 'ErrorPages',
//     meta: {
//       title: 'Error Pages',
//       icon: '404'
//     },
//     children: [
//       {
//         path: '403',
//         component: () => import('@/components/ErrorPage/403'),
//         name: 'Page401',
//         meta: { title: '403' }
//       },
//       {
//         path: '404',
//         component: () => import('@/components/ErrorPage/404'),
//         name: 'Page404',
//         meta: { title: '404' }
//       }
//     ]
//   },
//   // 404 page must be placed at the end !!!
//   { path: '*', redirect: '/404', hidden: true }
// ]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
