import { constantRoutes } from '@/router'
import { getMenu } from '@/api/user'
import { validatenull } from '@/utils/validate'
import { setStore, getStore } from '@/utils/store'
/* Layout */
import Layout from '@/layout'

export const initMenu = (router, menu) => {
  if (menu.length === 0) {
    return
  }
  router.addRoutes(formatRoutes(menu))
}

export const formatRoutes = (aMenu) => {
  const aRouter = []
  aMenu.forEach(oMenu => {
    const {
      path,
      component,
      name,
      icon,
      children
    } = oMenu

    if (!validatenull(component)) {
      const oRouter = {
        path: path,
        component: (resolve) => {
          let componentPath = ''
          if (component === 'Layout') {
            require([Layout], resolve)
            return
          } else {
            componentPath = component
            require([`../${componentPath}.vue`], resolve)
          }
        },
        name: name,
        // hidden: true,
        meta: { title: name, icon: icon, affix: true },
        children: validatenull(children) ? [] : formatRoutes(children)
      }
      aRouter.push(oRouter)
    }
  })
  return aRouter
}

/**
 * Use meta.role to determine if the current user has permission
 * @param roles
 * @param route
 */
function hasPermission(roles, route) {
  if (route.meta && route.meta.roles) {
    return roles.some(role => route.meta.roles.includes(role))
  } else {
    return true
  }
}

/**
 * Filter asynchronous routing tables by recursion
 * @param routes asyncRoutes
 * @param roles
 */
export function filterAsyncRoutes(routes, roles) {
  const res = []

  routes.forEach(route => {
    const tmp = { ...route }
    if (hasPermission(roles, tmp)) {
      if (tmp.children) {
        tmp.children = filterAsyncRoutes(tmp.children, roles)
      }
      res.push(tmp)
    }
  })

  return res
}

const state = {
  routes: getStore({ name: 'routes' }) || [],
  addRoutes: []
}

const mutations = {
  SET_ROUTERS: (state, routes) => {
    state.addRoutes = routes
    state.routes = constantRoutes.concat(routes)
    setStore({
      name: 'routes',
      content: state.routes,
      type: 'session'
    })
  }
}

const actions = {
  generateRoutes({ commit, state }, roles) {
    // console.log('test roles', roles)
    return new Promise(resolve => {
      getMenu().then((res) => {
        // console.log('test roles11111', res)
        var accessedRouters
        var asyncRouterMap = formatRoutes(res.data)
        // console.log('roles', roles)
        if (roles.indexOf('admin') >= 0) {
          accessedRouters = asyncRouterMap
        } else {
          accessedRouters = filterAsyncRoutes(asyncRouterMap, roles)
        }
        // console.log(accessedRouters)
        commit('SET_ROUTERS', accessedRouters)
        resolve(accessedRouters)
      })
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
